# Professional Projects

Cooking Diary

Cooking Diary

~3 years 7 months
  • Based on previous success, migrated Spine library from 3.6 to 4.2 version and convert around 2700 spine assets
  • Under direct CEO supervision, rapidly developed game features to increase ARPU and DAU in a lead role
  • Optimize floating point parse using fast_float in the internal game engine, which escalated runtime resource-intense JSON loading up to 8 times among all the internal projects
  • Made a seamless FlatBuffers integration and adopted 4 biggest and around 100 smaller intensively used config files, which boosted the game loading to 2 seconds. Automated source code generation based on the FlatBuffers’ schemes in CMake. Provided robust tool to convert JSON to binary format
  • Integrated the node system to optimize content integration, additionally enforced the Godot-like editor
  • Implemented the Unreal Engine like blueprint system, focused on the multithreading and performance
  • Migrated build system to CMake, slashing Windows builds from 45 to 2 minutes and Android from 80 to 4 minutes using unity build; retired legacy IDE projects; authored documentation; tripled throughput and cut Dev→QA→Dev cycles from 120 to ~20 minute
  • Refactored and multithreaded more than 20 internal tools to make them run from minutes to seconds
  • Ship the Google-SignIn to the iOS platform, which increased the DAU for 3%
Chef & Friends

Chef & Friends

~2 months
  • Determined complex game systems relations and parallelize their initialization, which amplified system initialization 3 times from 1 second to ~300 milliseconds
  • Profiled project building process and enhanced “CMake” which reduced whole build time from 14 to 7 minutes
Ravenhill

Ravenhill

~13 months
  • Under direct CEO supervision, rapidly replaced the foundation of game and changed the core logic to support top-view city features
  • Alongside with Head of Animation and animation team, migrated Spine library from 3.6 to 4.2 version, made a assets conversion tool-set to upgrade around 1000 spine assets, added in-game viewer to accelerate QA check; all to support physics in spine animations
  • Initiated and organized small team to replace loading screen to fast transition to increase DAU
  • Integrated Firebase Performance Monitoring for iOS and Android devices in one day
  • Discovered, analyzed, and optimized the game loading time from 5 to 1 second
  • Participate in migration from the legacy project to a modern internal game engine
  • Highlighted the performance issues by integrating Tracy library and guided QA and Dev teams within 3 days
  • Accelerate JSON to BSON conversion from ~5 minutes up to 30 seconds

New Internal Project

~10 months

  • Set up a new cross-platform project within a few weeks using modern CMake and a new game engine.
  • Built a standalone multithreaded Lua dialogue system in two weeks, allowing non-programmers to create complex dialogue trees and loops within minutes.
  • Reinvented the in-game widget system with a node-based, Figma-like editor that designers could use independently.
  • Worked closely with the engine team to improve and strengthen the new internal game engine.
  • Delivered robust utilities, tools, and modules for the team.

# Personal Projects

More projects on GitHub.